# Changelog

All notable changes to the R2MIDI project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.93] - 2025-06-08

### Changed
- Automatic version increment

## [0.1.92] - ## [0.1.92] - 2025-06-08

### Changed
- Automatic version increment

## [0.1.91] - ## [0.1.91] - 2025-06-08

### Changed
- Automatic version increment

## [0.1.90] - ## [0.1.90] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.89] - ## [0.1.89] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.88] - ## [0.1.88] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.87] - ## [0.1.87] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.86] - ## [0.1.86] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.85] - ## [0.1.85] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.84] - ## [0.1.84] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.83] - ## [0.1.83] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.82] - ## [0.1.82] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.81] - ## [0.1.81] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.80] - ## [0.1.80] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.79] - ## [0.1.79] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.78] - ## [0.1.78] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.77] - ## [0.1.77] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.76] - ## [0.1.76] - 2025-06-07

### Changed
- Automatic version increment

## [0.1.75] - ## [0.1.75] - 2025-06-06

### Changed
- Automatic version increment

## [0.1.74] - ## [0.1.74] - 2025-06-06

### Changed
- Automatic version increment

## [0.1.73] - ## [0.1.73] - 2025-06-06

### Changed
- Automatic version increment

## [0.1.72] - ## [0.1.72] - 2025-06-06

### Changed
- Automatic version increment

## [0.1.71] - ## [0.1.71] - 2025-06-06

### Changed
- Automatic version increment

## [0.1.70] - ## [0.1.70] - 2025-06-06

### Changed
- Automatic version increment

## [0.1.69] - ## [0.1.69] - 2025-06-06

### Changed
- Automatic version increment

## [0.1.68] - ## [0.1.68] - 2025-06-06

### Changed
- Automatic version increment

## [0.1.67] - ## [0.1.67] - 2025-06-06

### Changed
- Automatic version increment

## [0.1.66] - ## [0.1.66] - 2025-06-06

### Changed
- Automatic version increment

## [0.1.65] - ## [0.1.65] - 2025-06-06

### Added
- Added support for Linux system packaging
- Improved error handling in MIDI device detection

### Fixed
- Fixed issue with MIDI channel selection in the client UI
- Resolved compatibility issues with certain MIDI devices

### Changed
- Updated dependencies to latest versions
- Improved performance of preset loading

## [0.1.64] - 2025-05-15

### Added
- Initial public release
- Support for Windows, macOS, and Linux
- Basic MIDI preset selection functionality
- Integration with community preset repository